// (C) 2019-2025 GoodData Corporation
import React from "react";
import { useIntl } from "react-intl";
import { Button } from "@gooddata/sdk-ui-kit";
import cx from "classnames";
/**
 * This component displays two buttons Apply and Cancel.
 * Apply button is disabled when selection is not changed.
 * Cancel button discard changes and close AttributeFilter dropdown.
 *
 * @beta
 */
export const AttributeFilterDropdownActions = ({ isApplyDisabled, onApplyButtonClick, onCancelButtonClick, withoutApply, }) => {
    const intl = useIntl();
    const cancelText = intl.formatMessage({ id: "gs.list.cancel" });
    const closeText = intl.formatMessage({ id: "close" });
    const applyText = intl.formatMessage({ id: "gs.list.apply" });
    const cancelClassNames = withoutApply
        ? "gd-attribute-filter-close-button__next close-button s-close"
        : "gd-attribute-filter-cancel-button__next cancel-button s-cancel";
    return (React.createElement("div", { className: "gd-attribute-filter-dropdown-actions__next" },
        React.createElement("div", { className: "gd-attribute-filter-dropdown-actions-left-content__next" }),
        React.createElement("div", { className: "gd-attribute-filter-dropdown-actions-right-content__next" },
            React.createElement(Button, { className: cx(cancelClassNames, "gd-button-secondary gd-button-small"), onClick: onCancelButtonClick, value: withoutApply ? closeText : cancelText, title: withoutApply ? closeText : cancelText }),
            !withoutApply && (React.createElement(Button, { disabled: isApplyDisabled, className: "gd-attribute-filter-apply-button__next gd-button-action gd-button-small s-apply", onClick: onApplyButtonClick, value: applyText, title: applyText })))));
};
//# sourceMappingURL=AttributeFilterDropdownActions.js.map